@@ -6,15 +6,13 @@ test <- function(class = c("sf", "sp"), ...) {
   get_big_data("test", class, ...)
 }
 
-test_that("get_layer works with downloadable data", {
-  skip_if_not_installed("bcmapsdata")
-  skip_on_cran()
-  skip_on_actions()
-  expect_equal(get_layer("test", force = TRUE, ask = FALSE), "test")
-})
+# test_that("get_layer works with downloadable data", {
+#   skip_on_cran()
+#   skip_on_actions()
+#   expect_equal(get_layer("test", force = TRUE, ask = FALSE), "test")
+# })
 
 test_that("get_big_data works with specific release", {
-  skip_if_not_installed("bcmapsdata")
   skip_on_cran()
   skip_on_actions()
   expect_equal(get_big_data("test", "sf", "0.1.1", force = TRUE, ask = FALSE), "test")
@@ -25,7 +23,6 @@ test_that("get_big_data works with specific release", {
 })
 
 test_that("get_big_data works with latest release", {
-  skip_if_not_installed("bcmapsdata")
   skip_on_cran()
   skip_on_actions()
   expect_equal(get_big_data("test", "sf", "latest", force = TRUE, ask = FALSE), "test")
@@ -33,22 +30,19 @@ test_that("get_big_data works with latest release", {
 })
 
 test_that("get_big_data fails when file doesn't exist", {
-  skip_if_not_installed("bcmapsdata")
   skip_on_cran()
   skip_on_actions()
   expect_error(get_big_data("test", "sf", "0.1.0", force = TRUE, ask = FALSE), "No assets matching filename test.rds in 0.1.0 release")
 })
 
-test_that("check_write_to_data_dir works", {
-  skip_if_not_installed("bcmapsdata")
-  skip_on_cran()
-  skip_on_actions()
-  expect_message(check_write_to_data_dir(data_dir(), ask = FALSE), "Creating directory to hold bcmaps data")
-  expect_true(dir.exists(rappdirs::user_data_dir("bcmaps")))
-})
+# test_that("check_write_to_data_dir works", {
+#   skip_on_cran()
+#   skip_on_actions()
+#   expect_message(check_write_to_data_dir(data_dir(), ask = FALSE), "Creating directory to hold bcmaps data")
+#   expect_true(dir.exists(rappdirs::user_data_dir("bcmaps")))
+# })
 
 test_that("gh functions work with and without authentication", {
-  skip_if_not_installed("bcmapsdata")
   skip_on_travis()
   skip_on_cran()
   skip_on_actions()
